diff --git a/dumux/implicit/adaptive/adaptionhelper.hh b/dumux/implicit/adaptive/adaptionhelper.hh
index 4e39c499efcc437283c8f32b3ab044c46a3c9352..c4462861e865aa58b95a06fe7a3b070d02def0cf 100644
--- a/dumux/implicit/adaptive/adaptionhelper.hh
+++ b/dumux/implicit/adaptive/adaptionhelper.hh
@@ -350,7 +350,7 @@ public:
     /**
      * This methods stores reconstructed values into the cellData object, by
      * this setting a newly mapped solution to the storage container of the
-     * decoupled models.
+     * sequential models.
      *
      * \param adaptedValues Container for model-specific values to be adapted
      * \param u The variables to be stored
diff --git a/dumux/implicit/adaptive/gridadaptproperties.hh b/dumux/implicit/adaptive/gridadaptproperties.hh
index fb0741d893efa89d246234ec4c707f97438126e0..fb3928b944a3d8d4832b3d3cd0e71990e884f41b 100644
--- a/dumux/implicit/adaptive/gridadaptproperties.hh
+++ b/dumux/implicit/adaptive/gridadaptproperties.hh
@@ -33,7 +33,7 @@ namespace Dumux
 {
 namespace Properties
 {
-//! Grid adaption type tag for all decoupled models.
+//! Grid adaption type tag for all sequential models.
 NEW_TYPE_TAG(GridAdapt);
 
 //! Defines if the grid is h-adaptive
diff --git a/dumux/material/components/tabulatedcomponent.hh b/dumux/material/components/tabulatedcomponent.hh
index 9dd76f759c146635029ea1415f473ca0f3534fd6..8be50efb14dab5b425b319992b73bc7eb2a82140 100644
--- a/dumux/material/components/tabulatedcomponent.hh
+++ b/dumux/material/components/tabulatedcomponent.hh
@@ -280,7 +280,7 @@ public:
      * \brief The vapor pressure in \f$\mathrm{[Pa]}\f$ of the component at a given
      *        temperature.
      *
-     * The method is only called by the decoupled flash, so tabulating is omitted.
+     * The method is only called by the sequential flash, so tabulating is omitted.
      * \param pressure pressure of component in \f$\mathrm{[Pa]}\f$
      */
     static Scalar vaporTemperature(Scalar pressure)
diff --git a/dumux/material/constraintsolvers/compositionalflash.hh b/dumux/material/constraintsolvers/compositionalflash.hh
index a7d548b66218bdd09f15594b83bbd809940490e2..e4264ff71f27e9de6247a6945cf8af386e6002ef 100644
--- a/dumux/material/constraintsolvers/compositionalflash.hh
+++ b/dumux/material/constraintsolvers/compositionalflash.hh
@@ -38,7 +38,7 @@ namespace Dumux
 {
 /*!
  * \ingroup ConstraintSolver
- * \brief Flash calculation routines for compositional decoupled models
+ * \brief Flash calculation routines for compositional sequential models
  *
  *        Routines for isothermal and isobaric 2p2c and 1p2c flash.
  *  \tparam TypeTag The property Type Tag
@@ -75,7 +75,7 @@ public:
      * - determination of maximum solubilities (mole fractions) according to phase pressures
      * - comparison with Z1 to determine phase presence => phase mass fractions
      * - round off fluid properties
-     * \param fluidState The decoupled fluid State
+     * \param fluidState The sequential fluid State
      * \param Z1 Feed mass fraction: Mass of comp1 per total mass \f$\mathrm{[-]}\f$
      * \param phasePressure Vector holding the pressure \f$\mathrm{[Pa]}\f$
      * \param porosity Porosity \f$\mathrm{[-]}\f$
@@ -184,7 +184,7 @@ public:
      * - Check if we are in single phase condition
      * - Assign total concentration to the present phase
      *
-     * \param fluidState The decoupled fluid state
+     * \param fluidState The sequential fluid state
      * \param Z1 Feed mass fraction \f$\mathrm{[-]}\f$
      * \param phasePressure Vector holding the pressure \f$\mathrm{[Pa]}\f$
      * \param presentPhaseIdx Subdomain Index = Indication which phase is present
@@ -255,7 +255,7 @@ public:
      * - determination of the equilibrium constants from the fluid system
      * - determination of maximum solubilities (mole fractions) according to phase pressures
      * - round off fluid properties
-     * \param fluidState The decoupled fluid state
+     * \param fluidState The sequential fluid state
      * \param saturation Saturation of phase 1 \f$\mathrm{[-]}\f$
      * \param phasePressure Vector holding the pressure \f$\mathrm{[Pa]}\f$
      * \param porosity Porosity \f$\mathrm{[-]}\f$
diff --git a/dumux/material/fluidstates/pseudo1p2c.hh b/dumux/material/fluidstates/pseudo1p2c.hh
index 9f7afd26e3fefec49f616218a82f50dead74806e..3cb832e4c3ba347d3fd562e3e424ed034cd3ddf7 100644
--- a/dumux/material/fluidstates/pseudo1p2c.hh
+++ b/dumux/material/fluidstates/pseudo1p2c.hh
@@ -36,7 +36,7 @@ namespace Dumux
  *  It is used in case of a multiphysics approach. For the non-present phase,
  *  no information is stored but 0-values are returned to allow for general output
  *  methods.
- *  The "flash" calculation routines are in the decoupled flash constrain solver, see
+ *  The "flash" calculation routines are in the sequential flash constrain solver, see
  *  Dumux::CompositionalFlash .
  *  \tparam TypeTag The property Type Tag
  */
diff --git a/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressureproperties.hh b/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressureproperties.hh
index 0066de093ffe6a600f18a7264544431ef0ebfd70..753992fe9ce87946787ff718aa689dc5f77c022d 100644
--- a/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressureproperties.hh
+++ b/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressureproperties.hh
@@ -27,8 +27,8 @@
  * \brief Defines the properties required for finite volume pressure models
  */
 
-#ifndef DUMUX_FVPRESSUREPORPERTIES1P_DECOUPLED_HH
-#define DUMUX_FVPRESSUREPORPERTIES1P_DECOUPLED_HH
+#ifndef DUMUX_FVPRESSUREPORPERTIES1P_SEQUENTIAL_HH
+#define DUMUX_FVPRESSUREPORPERTIES1P_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/1p/sequential/diffusion/properties.hh>
diff --git a/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh b/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
index 1d50dc14fd63bbd8d0d1429f8ad7e2f53db06d8f..fd08ddce2a5069a457035d68ad5b43e1866e300c 100644
--- a/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
+++ b/dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
@@ -27,8 +27,8 @@
  * \brief Defines the properties required for finite volume pressure models
  */
 
-#ifndef DUMUX_FVPRESSUREVELOCITYPORPERTIES1P_DECOUPLED_HH
-#define DUMUX_FVPRESSUREVELOCITYPORPERTIES1P_DECOUPLED_HH
+#ifndef DUMUX_FVPRESSUREVELOCITYPORPERTIES1P_SEQUENTIAL_HH
+#define DUMUX_FVPRESSUREVELOCITYPORPERTIES1P_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/1p/sequential/diffusion/properties.hh>
diff --git a/dumux/porousmediumflow/2p/sequential/celldataadaptive.hh b/dumux/porousmediumflow/2p/sequential/celldataadaptive.hh
index 5fe0a9fcb7f239e3f9278193f31973d7b0c0f375..22bf67ccca23e0ccd8941e017f47b4d0500e0575 100644
--- a/dumux/porousmediumflow/2p/sequential/celldataadaptive.hh
+++ b/dumux/porousmediumflow/2p/sequential/celldataadaptive.hh
@@ -138,7 +138,7 @@ public:
     /**
      * This methods stores reconstructed values into the cellData object, by
      * this setting a newly mapped solution to the storage container of the
-     * decoupled models.
+     * sequential models.
      *
      * \param adaptedValues Container for model-specific values to be adapted
      * \param element The element where things are stored.
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressure.hh b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressure.hh
index 89c04798f33bb39f67346d5c35efafa909cbdd18..1c22f06e23b14fdb1a372884e877513570224d1d 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressure.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressure.hh
@@ -90,7 +90,7 @@ namespace Dumux
  *
  *  In the IMPES models the default setting is:
  *
- *  - formulation: \f$ p_w-S_w \f$ (Property: \a Formulation defined as \a DecoupledTwoPCommonIndices::pwsw)
+ *  - formulation: \f$ p_w-S_w \f$ (Property: \a Formulation defined as \a SequentialTwoPCommonIndices::pwsw)
  *
  *  - compressibility: disabled (Property: \a EnableCompressibility set to \a false)
  *
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressureproperties.hh b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressureproperties.hh
index 446fce95e331ae9c9162729a90120f90aba32e9b..97fc8f91731407c4c11cf69cc74cb1cf214773fd 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressureproperties.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressureproperties.hh
@@ -27,8 +27,8 @@
  * \brief Defines the properties required for finite volume pressure models in a two-phase sequential model.
  */
 
-#ifndef DUMUX_FVPRESSUREPORPERTIES2P_DECOUPLED_HH
-#define DUMUX_FVPRESSUREPORPERTIES2P_DECOUPLED_HH
+#ifndef DUMUX_FVPRESSUREPORPERTIES2P_SEQUENTIAL_HH
+#define DUMUX_FVPRESSUREPORPERTIES2P_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/2p/sequential/diffusion/properties.hh>
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurepropertiesadaptive.hh b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurepropertiesadaptive.hh
index 486a44c9c407ae3550e23b176e457c278730ebdd..4a0f014824941746bb75401aa89f89f7f1f0322c 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurepropertiesadaptive.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurepropertiesadaptive.hh
@@ -27,8 +27,8 @@
  * \brief Defines the properties required for finite volume pressure models in a two-phase sequential model.
  */
 
-#ifndef DUMUX_FVPRESSUREPORPERTIES2P_ADAPTIVE_DECOUPLED_HH
-#define DUMUX_FVPRESSUREPORPERTIES2P_ADAPTIVE_DECOUPLED_HH
+#ifndef DUMUX_FVPRESSUREPORPERTIES2P_ADAPTIVE_SEQUENTIAL_HH
+#define DUMUX_FVPRESSUREPORPERTIES2P_ADAPTIVE_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/2p/sequential/diffusion/properties.hh>
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
index 0ee673447793f0f1b915f71d53148b87f9260d0d..902f553e58b533f54db283207c057253e1ebadb5 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressurevelocityproperties.hh
@@ -27,8 +27,8 @@
  * \brief Defines the properties required for finite volume pressure models
  */
 
-#ifndef DUMUX_FVPRESSUREVELOCITYPORPERTIES2P_DECOUPLED_HH
-#define DUMUX_FVPRESSUREVELOCITYPORPERTIES2P_DECOUPLED_HH
+#ifndef DUMUX_FVPRESSUREVELOCITYPORPERTIES2P_SEQUENTIAL_HH
+#define DUMUX_FVPRESSUREVELOCITYPORPERTIES2P_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/2p/sequential/diffusion/properties.hh>
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressureproperties.hh b/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressureproperties.hh
index 6f1d28f8f1580ed075c595165aa1712c10898811..a081d184fb9b3f65fb137c8f3ba97bc5cc2bf05a 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressureproperties.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressureproperties.hh
@@ -17,8 +17,8 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
  *****************************************************************************/
 
-#ifndef DUMUX_MIMETICPROPERTIES2P_DECOUPLED_HH
-#define DUMUX_MIMETICPROPERTIES2P_DECOUPLED_HH
+#ifndef DUMUX_MIMETICPROPERTIES2P_SEQUENTIAL_HH
+#define DUMUX_MIMETICPROPERTIES2P_SEQUENTIAL_HH
 
 /*!
  * \ingroup IMPES
diff --git a/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressurepropertiesadaptive.hh b/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressurepropertiesadaptive.hh
index d1c53f96a8fa790df801e01eb88b072cf35fdc6e..c931dbc9f2da390fc0f3e2ca2e7eb1d87ca24d01 100644
--- a/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressurepropertiesadaptive.hh
+++ b/dumux/porousmediumflow/2p/sequential/diffusion/mimetic/pressurepropertiesadaptive.hh
@@ -18,8 +18,8 @@
  *****************************************************************************/
 
 
-#ifndef DUMUX_MIMETICPROPERTIES2PADAPTIVE_DECOUPLED_HH
-#define DUMUX_MIMETICPROPERTIES2PADAPTIVE_DECOUPLED_HH
+#ifndef DUMUX_MIMETICPROPERTIES2PADAPTIVE_SEQUENTIAL_HH
+#define DUMUX_MIMETICPROPERTIES2PADAPTIVE_SEQUENTIAL_HH
 
 /*!
  * \ingroup IMPES
diff --git a/dumux/porousmediumflow/2p/sequential/properties.hh b/dumux/porousmediumflow/2p/sequential/properties.hh
index f16887684b5e76463eabbabaae55a7747684a974..d553433139d106225ed4378f65307122405e1bd0 100644
--- a/dumux/porousmediumflow/2p/sequential/properties.hh
+++ b/dumux/porousmediumflow/2p/sequential/properties.hh
@@ -108,12 +108,12 @@ SET_INT_PROP(SequentialTwoP, NumPhases, 2);//!< The number of phases in the 2p m
 SET_INT_PROP(SequentialTwoP, NumComponents, 1); //!< Each phase consists of 1 pure component
 
 //! Set \f$p_w\f$-\f$S_w\f$ formulation as default two-phase formulation
-SET_INT_PROP(SequentialTwoP, Formulation, DecoupledTwoPCommonIndices::pwsw);
+SET_INT_PROP(SequentialTwoP, Formulation, SequentialTwoPCommonIndices::pwsw);
 
 //! Chose the set of indices depending on the chosen formulation
 SET_PROP(SequentialTwoP, Indices)
 {
-typedef DecoupledTwoPIndices<GET_PROP_VALUE(TypeTag, Formulation), 0> type;
+    typedef SequentialTwoPIndices<GET_PROP_VALUE(TypeTag, Formulation), 0> type;
 };
 
 //! Set the default pressure formulation according to the chosen two-phase formulation
diff --git a/dumux/porousmediumflow/2p/sequential/transport/cellcentered/saturation.hh b/dumux/porousmediumflow/2p/sequential/transport/cellcentered/saturation.hh
index 465eaccdbb09b8198f9613c1deba55a9f423535c..09cbcb93ffe2a8f265c7dcb513fa40b46bc7f91b 100644
--- a/dumux/porousmediumflow/2p/sequential/transport/cellcentered/saturation.hh
+++ b/dumux/porousmediumflow/2p/sequential/transport/cellcentered/saturation.hh
@@ -63,7 +63,7 @@ namespace Dumux
  *
  *  In the IMPES models the default setting is:
  *
- * formulation: \f$ p_w \f$ - \f$ S_w \f$ (Property: \a Formulation defined as \a DecoupledTwoPCommonIndices::pwsw)
+ * formulation: \f$ p_w \f$ - \f$ S_w \f$ (Property: \a Formulation defined as \a SequentialTwoPCommonIndices::pwsw)
  *
  * compressibility: disabled (Property: \a EnableCompressibility set to \a false)
  *
diff --git a/dumux/porousmediumflow/2p/sequential/transport/problem.hh b/dumux/porousmediumflow/2p/sequential/transport/problem.hh
index abc20e82ac242c03586dd13f94fccb26a05c2da3..373594998a3c4ba245fb952e26179d3932f38c91 100644
--- a/dumux/porousmediumflow/2p/sequential/transport/problem.hh
+++ b/dumux/porousmediumflow/2p/sequential/transport/problem.hh
@@ -43,7 +43,7 @@ SET_TYPE_PROP(TransportTwoP, Velocity, FVVelocityDefault<TypeTag>);
 /*!
  * \ingroup Saturation2p
  * \ingroup IMPETproblems
- * \brief  Base class for a decoupled two-phase transport problem
+ * \brief  Base class for a sequential two-phase transport problem
  *
  * \tparam TypeTag The problem Type Tag
  */
diff --git a/dumux/porousmediumflow/2p/sequential/transport/properties.hh b/dumux/porousmediumflow/2p/sequential/transport/properties.hh
index 30452e8e03602b9af433bd9d60bd7b6ce492bc2c..5cc855d271a3ea2a26249526bb7c4ba4ca399496 100644
--- a/dumux/porousmediumflow/2p/sequential/transport/properties.hh
+++ b/dumux/porousmediumflow/2p/sequential/transport/properties.hh
@@ -40,7 +40,7 @@ namespace Properties
 // Type tags tags
 //////////////////////////////////////////////////////////////////
 
-//! The type tag for transport part of a decoupled two-phase model
+//! The type tag for transport part of a sequential two-phase model
 NEW_TYPE_TAG(TransportTwoP, INHERITS_FROM(Transport, SequentialTwoP));
 
 //////////////////////////////////////////////////////////////////
diff --git a/dumux/porousmediumflow/2p2c/sequential/celldata.hh b/dumux/porousmediumflow/2p2c/sequential/celldata.hh
index 55edd79a0c858ee6c1684b24bc543dfcf729f80f..63921ce557db9f6e617895cf3b4c5a4c39fb4907 100644
--- a/dumux/porousmediumflow/2p2c/sequential/celldata.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/celldata.hh
@@ -33,7 +33,7 @@ namespace Dumux
  * \ingroup multiphysics multiphase
  */
 //! Storage container for discretized data of the constitutive relations for one element
-/*! This class stores all cell-centered (FV-Scheme) values for decoupled compositional two-phase flow
+/*! This class stores all cell-centered (FV-Scheme) values for sequential compositional two-phase flow
  * models that are used by both pressure and transport model. All fluid data are already stored in the
  * fluidstate, so the CellData contains the fluidstate object for the current element.
  * At the moment, the compositional model does not use fluxVariables that are stored on the interfaces.
diff --git a/dumux/porousmediumflow/2p2c/sequential/celldataadaptive.hh b/dumux/porousmediumflow/2p2c/sequential/celldataadaptive.hh
index 46f7e75645f0393cc3f7b79e20fafa1e80ceffd9..1108764718e49c1d4cf3b14d7e6330832f1da20c 100644
--- a/dumux/porousmediumflow/2p2c/sequential/celldataadaptive.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/celldataadaptive.hh
@@ -173,7 +173,7 @@ public:
     /**
      * This methods stores reconstructed values into the cellData object, by
      * this setting a newly mapped solution to the storage container of the
-     * decoupled models.
+     * sequential models.
      * In new cells, update estimate does not give meaningful results. We therefore
      * copy volume derivatives from old time step, and indicate that those are already availabe.
      *
diff --git a/dumux/porousmediumflow/2p2c/sequential/fluxdata.hh b/dumux/porousmediumflow/2p2c/sequential/fluxdata.hh
index aa83332e37f98b78a389d391c8fc7177575400b6..ac34bfdb061c4cf6f7d8d460fccb02d6d93e7d92 100644
--- a/dumux/porousmediumflow/2p2c/sequential/fluxdata.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/fluxdata.hh
@@ -33,7 +33,7 @@ namespace Dumux
  */
 //! Class including the variables and data of discretized data of the constitutive relations.
 /*! The variables of two-phase flow, which are one pressure and one saturation are stored in this class.
- * Additionally, a velocity needed in the transport part of the decoupled two-phase flow is stored,
+ * Additionally, a velocity needed in the transport part of the sequential two-phase flow is stored,
  * as well as discretized data of constitutive relationships like mobilities, fractional flow functions
  * and capillary pressure. Thus, they have to be callculated just once in every time step or every iteration step.
  *
diff --git a/dumux/porousmediumflow/2p2c/sequential/fv3dpressureadaptive.hh b/dumux/porousmediumflow/2p2c/sequential/fv3dpressureadaptive.hh
index 17b92e12093e137c80a5c6a3b8a734f115e011e0..a17e52230f99fddd4e932bccdf5ea3e6a7f3fa19 100644
--- a/dumux/porousmediumflow/2p2c/sequential/fv3dpressureadaptive.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/fv3dpressureadaptive.hh
@@ -46,8 +46,8 @@ namespace Dumux
 {
 namespace Properties
 {
-SET_TYPE_PROP(DecoupledTwoPTwoCAdaptive, MPFAInteractionVolume, Dumux::FvMpfaL3dInteractionVolumeAdaptive<TypeTag>);
-SET_TYPE_PROP(DecoupledTwoPTwoCAdaptive, MPFAInteractionVolumeContainer, Dumux::FvMpfaL3d2P2CInteractionVolumeContainerAdaptive<TypeTag>);
+SET_TYPE_PROP(SequentialTwoPTwoCAdaptive, MPFAInteractionVolume, Dumux::FvMpfaL3dInteractionVolumeAdaptive<TypeTag>);
+SET_TYPE_PROP(SequentialTwoPTwoCAdaptive, MPFAInteractionVolumeContainer, Dumux::FvMpfaL3d2P2CInteractionVolumeContainerAdaptive<TypeTag>);
 }
 
 //! The finite volume model for the solution of the compositional pressure equation
diff --git a/dumux/porousmediumflow/2p2c/sequential/fvpressure.hh b/dumux/porousmediumflow/2p2c/sequential/fvpressure.hh
index 0bf44abb1b5fdfa73037282cfb04358ea0655ca2..4b6bd2f23180feb8e10ad174c5e0201ca0d270eb 100644
--- a/dumux/porousmediumflow/2p2c/sequential/fvpressure.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/fvpressure.hh
@@ -1024,7 +1024,7 @@ void FVPressure2P2C<TypeTag>::updateMaterialLawsInElement(const Element& element
     Scalar massn = sumConc * fluidState.phaseMassFraction(nPhaseIdx);
 
     if ((cellData.density(wPhaseIdx)*cellData.density(nPhaseIdx)) == 0)
-        DUNE_THROW(Dune::MathError, "Decoupled2p2c::postProcessUpdate: try to divide by 0 density");
+        DUNE_THROW(Dune::MathError, "Sequential2p2c::postProcessUpdate: try to divide by 0 density");
     Scalar vol = massw / cellData.density(wPhaseIdx) + massn / cellData.density(nPhaseIdx);
     if (Dune::FloatCmp::ne<Scalar, Dune::FloatCmp::absolute>(problem().timeManager().timeStepSize(), 0.0, 1.0e-30))
     {
@@ -1032,7 +1032,7 @@ void FVPressure2P2C<TypeTag>::updateMaterialLawsInElement(const Element& element
 
         if (std::isnan(cellData.volumeError()))
         {
-            DUNE_THROW(Dune::MathError, "Decoupled2p2c::postProcessUpdate:\n"
+            DUNE_THROW(Dune::MathError, "Sequential2p2c::postProcessUpdate:\n"
                     << "volErr[" << eIdxGlobal << "] isnan: vol = " << vol
                     << ", massw = " << massw << ", rho_l = " << cellData.density(wPhaseIdx)
                     << ", massn = " << massn << ", rho_g = " << cellData.density(nPhaseIdx)
diff --git a/dumux/porousmediumflow/2p2c/sequential/variableclassadaptive.hh b/dumux/porousmediumflow/2p2c/sequential/variableclassadaptive.hh
index 13ab16e3535225ed94f90a5a20b247dfb13fe059..f1ac90d370971131a83306ec7dbbc4741ee4a904 100644
--- a/dumux/porousmediumflow/2p2c/sequential/variableclassadaptive.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/variableclassadaptive.hh
@@ -131,7 +131,7 @@ public:
         ParentType(gridView), grid_(gridView.grid())
     {}
 
-    //! Resizes decoupled variable vectors
+    //! Resizes sequential variable vectors
     /*! Method that change the size of the vectors for h-adaptive simulations, and clears recently
      * stored transmissibility matrices for the newly adapted grid.
      *
diff --git a/dumux/porousmediumflow/sequential/gridadaptproperties.hh b/dumux/porousmediumflow/sequential/gridadaptproperties.hh
index 18a2d579d554b8042ed3ba3132ec4249e0143f15..a6d929616865cdc4a9d9d701feef96cd89cb32ee 100644
--- a/dumux/porousmediumflow/sequential/gridadaptproperties.hh
+++ b/dumux/porousmediumflow/sequential/gridadaptproperties.hh
@@ -33,7 +33,7 @@ namespace Dumux
 {
 namespace Properties
 {
-//! Grid adaption type tag for all decoupled models.
+//! Grid adaption type tag for all sequential models.
 NEW_TYPE_TAG(GridAdaptTypeTag);
 
 //! Defines if the grid is h-adaptive
diff --git a/dumux/porousmediumflow/sequential/impet.hh b/dumux/porousmediumflow/sequential/impet.hh
index 295b2608042b5b26c91bd3824fa532d69e261d2c..c79b86b463e601a6f9c012ec59eb6c4e59321277 100644
--- a/dumux/porousmediumflow/sequential/impet.hh
+++ b/dumux/porousmediumflow/sequential/impet.hh
@@ -32,7 +32,7 @@ namespace Dumux
  * \ingroup IMPET
  * \brief IMplicit Pressure Explicit Transport (IMPET) scheme for the solution of weakly coupled diffusion-transport formulations.
  *
- * The model implements the decoupled equations of two-phase flow.
+ * The model implements the sequential equations of two-phase flow.
  * These equations can be derived from the two-phase flow equations shown for the two-phase box model (TwoPBoxModel).
  * The first equation to solve is a pressure equation of elliptic character.
  * The second one is a transport equation (e.g. for saturation, concentration,...), which can be hyperbolic or parabolic.
diff --git a/dumux/porousmediumflow/sequential/mimetic/properties.hh b/dumux/porousmediumflow/sequential/mimetic/properties.hh
index d1169e724cf00f95bfade90c5159893b54267a2b..b3bf876127b4f981412f7be2f4277ebf9f94a5ed 100644
--- a/dumux/porousmediumflow/sequential/mimetic/properties.hh
+++ b/dumux/porousmediumflow/sequential/mimetic/properties.hh
@@ -26,8 +26,8 @@
  * \brief Defines the basic properties required for a mimetic method.
  */
 
-#ifndef DUMUX_MIMETICPROPERTIES_DECOUPLED_HH
-#define DUMUX_MIMETICPROPERTIES_DECOUPLED_HH
+#ifndef DUMUX_MIMETICPROPERTIES_SEQUENTIAL_HH
+#define DUMUX_MIMETICPROPERTIES_SEQUENTIAL_HH
 
 //Dumux-includes
 #include <dumux/porousmediumflow/sequential/properties.hh>
diff --git a/dumux/porousmediumflow/sequential/onemodelproblem.hh b/dumux/porousmediumflow/sequential/onemodelproblem.hh
index e8d8ca633804889707aced7a0c9c30e257510be6..96575f4cd24b113a52a778bfa80885d2ec1c0f9c 100644
--- a/dumux/porousmediumflow/sequential/onemodelproblem.hh
+++ b/dumux/porousmediumflow/sequential/onemodelproblem.hh
@@ -27,7 +27,7 @@
 
 /**
  * @file
- * @brief  Base class for definition of an decoupled diffusion (pressure) or transport problem
+ * @brief  Base class for definition of an sequential diffusion (pressure) or transport problem
  */
 
 namespace Dumux
@@ -35,7 +35,7 @@ namespace Dumux
 
 /*! \ingroup IMPET
  *
- * @brief Base class for definition of an decoupled diffusion (pressure) or transport problem
+ * @brief Base class for definition of an sequential diffusion (pressure) or transport problem
  *
  * @tparam TypeTag The Type Tag
  */
diff --git a/dumux/porousmediumflow/sequential/properties.hh b/dumux/porousmediumflow/sequential/properties.hh
index 6610fbe1c3d5c645351526949543163feaf46af4..3555b66464c583ef793f9df78b21d27be044d99c 100644
--- a/dumux/porousmediumflow/sequential/properties.hh
+++ b/dumux/porousmediumflow/sequential/properties.hh
@@ -40,7 +40,7 @@ namespace Properties
 // Type tags
 //////////////////////////////////////////////////////////////////
 
-//! Create a type tag for all decoupled models
+//! Create a type tag for all sequential models
 NEW_TYPE_TAG(SequentialModel, INHERITS_FROM(NumericModel, GridAdaptTypeTag));
 
 //! DEPRECATED Since compile-time detection is "impossible," a run-time check will be performed in start.hh
diff --git a/dumux/porousmediumflow/sequential/variableclass.hh b/dumux/porousmediumflow/sequential/variableclass.hh
index facc8cb1290a5b0f44878dc2bdd303994696518d..25a1e17554f3a892a13ccec99bf92a3d6b2cae59 100644
--- a/dumux/porousmediumflow/sequential/variableclass.hh
+++ b/dumux/porousmediumflow/sequential/variableclass.hh
@@ -92,7 +92,7 @@ public:
         cellDataVector_.resize(gridView_.size(0));
     }
 
-    //! Resizes decoupled variable vectors
+    //! Resizes sequential variable vectors
     /*! Method that change the size of the vectors for h-adaptive simulations.
      *
      *\param size Size of the current (refined and coarsened) grid
diff --git a/test/porousmediumflow/1p/sequential/CMakeLists.txt b/test/porousmediumflow/1p/sequential/CMakeLists.txt
index df72922bfe3e9205155dac44ab0dad3078ee31fa..b2aa2a5ce2c328a933e77f3affa1b465242deede 100644
--- a/test/porousmediumflow/1p/sequential/CMakeLists.txt
+++ b/test/porousmediumflow/1p/sequential/CMakeLists.txt
@@ -38,4 +38,4 @@ test_diffusionproblem3d.hh
 test_diffusionproblem.hh
 test_diffusionspatialparams3d.hh
 test_diffusionspatialparams.hh
-DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/decoupled/1p)
+DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/porousmediumflow/1p/sequential)
diff --git a/test/porousmediumflow/1p/sequential/test_1p.cc b/test/porousmediumflow/1p/sequential/test_1p.cc
index ac41e42e40ebc6ae887c32c67c8a267c0c89ae09..017e61e72e140a52d38e22bf4bf44e43df23e88c 100644
--- a/test/porousmediumflow/1p/sequential/test_1p.cc
+++ b/test/porousmediumflow/1p/sequential/test_1p.cc
@@ -20,7 +20,7 @@
  * \file
  *
  * \ingroup IMPETtests
- * \brief test for the decoupled one-phase model.
+ * \brief test for the sequential one-phase model.
  */
 #include <config.h>
 
diff --git a/test/porousmediumflow/1p/sequential/test_1pproblem.hh b/test/porousmediumflow/1p/sequential/test_1pproblem.hh
index 61d2b00acea1c97aa1a4f3adb6844f4c756b1cd9..666124e33e07bc301fb3c5a192eb9e53aac48c4a 100644
--- a/test/porousmediumflow/1p/sequential/test_1pproblem.hh
+++ b/test/porousmediumflow/1p/sequential/test_1pproblem.hh
@@ -19,7 +19,7 @@
 /*!
  * \file
  *
- * \brief test problem for the decoupled one-phase model.
+ * \brief test problem for the sequential one-phase model.
  */
 #ifndef DUMUX_TEST_1P_PROBLEM_HH
 #define DUMUX_TEST_1P_PROBLEM_HH
@@ -74,7 +74,7 @@ SET_TYPE_PROP(TestProblemOneP, Problem, Dumux::TestProblemOneP<TypeTag>);
 /*!
  * \ingroup IMPETtests
  *
- * \brief test problem for the decoupled one-phase model.
+ * \brief test problem for the sequential one-phase model.
  */
 template<class TypeTag>
 class TestProblemOneP: public DiffusionProblem1P<TypeTag >
diff --git a/test/porousmediumflow/1p/sequential/test_diffusion.input b/test/porousmediumflow/1p/sequential/test_diffusion.input
new file mode 100644
index 0000000000000000000000000000000000000000..05e0fbbdf4e86debb6c1cfd368e877dd00208ddd
--- /dev/null
+++ b/test/porousmediumflow/1p/sequential/test_diffusion.input
@@ -0,0 +1,4 @@
+[Grid]
+LowerLeft = 0 0
+UpperRight = 1 1
+Refinement = 3
diff --git a/test/porousmediumflow/1p/sequential/test_diffusionproblem.hh b/test/porousmediumflow/1p/sequential/test_diffusionproblem.hh
index e7bf53dec0acd7eb0e1a48c01a93cc89bd6ceda5..b9ae58c06070d5dd77d99d26dcae7891ead2cb44 100644
--- a/test/porousmediumflow/1p/sequential/test_diffusionproblem.hh
+++ b/test/porousmediumflow/1p/sequential/test_diffusionproblem.hh
@@ -139,7 +139,7 @@ SET_BOOL_PROP(MimeticPressure2PTestProblem, ProblemEnableGravity, false);
 }
 
 /*!
- * \ingroup DecoupledProblems
+ * \ingroup SequentialProblems
  *
  * \brief test problem for diffusion models from the FVCA5 benchmark.
  *
diff --git a/test/porousmediumflow/2p/sequential/CMakeLists.txt b/test/porousmediumflow/2p/sequential/CMakeLists.txt
index a299be0b2dbffe0a2bb8e9d2c3862840ae8fe0d3..6d17d535f9c3c55be4186517615c0298fb1e3a4c 100644
--- a/test/porousmediumflow/2p/sequential/CMakeLists.txt
+++ b/test/porousmediumflow/2p/sequential/CMakeLists.txt
@@ -130,4 +130,4 @@ test_mpfa2pspatialparams.hh
 test_transport.cc
 test_transportproblem.hh
 test_transportspatialparams.hh
-DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/decoupled/2p)
+DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/porousmediumflow/2p/sequential)
diff --git a/test/porousmediumflow/2p/sequential/test_3d2pproblem.hh b/test/porousmediumflow/2p/sequential/test_3d2pproblem.hh
index 8b3316d62a17ba177c74f49f83f4602997a50910..5c31f7c710a50d1f0eba413c00915664c09b870a 100644
--- a/test/porousmediumflow/2p/sequential/test_3d2pproblem.hh
+++ b/test/porousmediumflow/2p/sequential/test_3d2pproblem.hh
@@ -88,7 +88,7 @@ public:
 };
 
 #if PROBLEM == 1
-SET_INT_PROP(ThreeDTwoPTestProblem, Formulation, DecoupledTwoPCommonIndices::pnSw);
+SET_INT_PROP(ThreeDTwoPTestProblem, Formulation, SequentialTwoPCommonIndices::pnSw);
 #endif
 
 // Set the spatial parameters
diff --git a/test/porousmediumflow/2p/sequential/test_impesproblem.hh b/test/porousmediumflow/2p/sequential/test_impesproblem.hh
index 7d0b0a345109e0ec4949aee34059b3ced7417fac..32b6367768593fe85b85249123c2865c6ce8d0b4 100644
--- a/test/porousmediumflow/2p/sequential/test_impesproblem.hh
+++ b/test/porousmediumflow/2p/sequential/test_impesproblem.hh
@@ -73,16 +73,14 @@ SET_TYPE_PROP(IMPESTestProblem, Problem, Dumux::IMPESTestProblem<TypeTag>);
 ////////////////////////////////////////////////////////////////////////
 //Switch to a p_n-S_w formulation
 //
-//SET_INT_PROP(IMPESTestProblem, Formulation,
-//        DecoupledTwoPCommonIndices::pnsn);
+//SET_INT_PROP(IMPESTestProblem, Formulation, SequentialTwoPCommonIndices::pnsn);
 //
 ////////////////////////////////////////////////////////////////////////
 
 ////////////////////////////////////////////////////////////////////////
 //Switch to a p_global-S_w formulation
 //
-//SET_INT_PROP(IMPESTestProblem, Formulation,
-//        DecoupledTwoPCommonIndices::pGlobalSw);
+//SET_INT_PROP(IMPESTestProblem, Formulation, SequentialTwoPCommonIndices::pGlobalSw);
 //
 //Define the capillary pressure term in the transport equation -> only needed in case of a p_global-S_w formulation!
 //SET_TYPE_PROP(IMPESTestProblem, CapillaryFlux, CapillaryDiffusion<TypeTag>);
diff --git a/test/porousmediumflow/2p/sequential/test_mpfa2pproblem.hh b/test/porousmediumflow/2p/sequential/test_mpfa2pproblem.hh
index dcd40978ed5e163fb920c2c9d484d72baeb17cf5..fede79e600fc36ade451d2d0430a8eb4a7996791 100644
--- a/test/porousmediumflow/2p/sequential/test_mpfa2pproblem.hh
+++ b/test/porousmediumflow/2p/sequential/test_mpfa2pproblem.hh
@@ -108,7 +108,7 @@ public:
 #endif
 
 #if PROBLEM == 1
-SET_INT_PROP(MPFATwoPTestProblem, Formulation, DecoupledTwoPCommonIndices::pnsw);
+SET_INT_PROP(MPFATwoPTestProblem, Formulation, SequentialTwoPCommonIndices::pnsw);
 #endif
 
 #if PROBLEM == 2
diff --git a/test/porousmediumflow/2p/sequential/test_transportproblem.hh b/test/porousmediumflow/2p/sequential/test_transportproblem.hh
index b6b4bb3438e49ddb6aede79144b850db40a68950..727ae91bb30ea1680a06082adc2bb17d5cc322c0 100644
--- a/test/porousmediumflow/2p/sequential/test_transportproblem.hh
+++ b/test/porousmediumflow/2p/sequential/test_transportproblem.hh
@@ -73,8 +73,7 @@ public:
     typedef Dumux::LiquidPhase<Scalar, Dumux::Unit<Scalar> > type;
 };
 
-SET_INT_PROP(TransportTestProblem, VelocityFormulation,
-        DecoupledTwoPCommonIndices::velocityTotal);
+SET_INT_PROP(TransportTestProblem, VelocityFormulation, SequentialTwoPCommonIndices::velocityTotal);
 }
 
 /*!
diff --git a/test/porousmediumflow/2p2c/sequential/CMakeLists.txt b/test/porousmediumflow/2p2c/sequential/CMakeLists.txt
index 468de17d2fcb2a9b02230255d631c175819b477e..c2cab2be40a18152961f0b8113f95ceed6637b25 100644
--- a/test/porousmediumflow/2p2c/sequential/CMakeLists.txt
+++ b/test/porousmediumflow/2p2c/sequential/CMakeLists.txt
@@ -39,4 +39,4 @@ test_dec2p2cproblem.hh
 test_dec2p2c_spatialparams.hh
 test_multiphysics2p2c.cc
 test_multiphysics2p2cproblem.hh
-DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/decoupled/2p2c)
+DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/test/porousmediumflow/2p2c/sequential)
diff --git a/test/porousmediumflow/2p2c/sequential/test_adaptive2p2c3dproblem.hh b/test/porousmediumflow/2p2c/sequential/test_adaptive2p2c3dproblem.hh
index ae55d13e621b1f4c458e91f5e30e9faea5fc11f2..486013d3710a5c8f93da040c9f2831baf1add0f1 100644
--- a/test/porousmediumflow/2p2c/sequential/test_adaptive2p2c3dproblem.hh
+++ b/test/porousmediumflow/2p2c/sequential/test_adaptive2p2c3dproblem.hh
@@ -48,7 +48,7 @@ class Adaptive2p2c3d;
 
 namespace Properties
 {
-NEW_TYPE_TAG(Adaptive2p2c3d, INHERITS_FROM(DecoupledTwoPTwoCAdaptive,Test2P2CSpatialParams, MPFAProperties));
+NEW_TYPE_TAG(Adaptive2p2c3d, INHERITS_FROM(SequentialTwoPTwoCAdaptive,Test2P2CSpatialParams, MPFAProperties));
 
 // Set the grid type
 #if HAVE_DUNE_ALUGRID
diff --git a/tutorial/solutions_sequential/Ex1_a_input.diff b/tutorial/solutions_sequential/Ex1_a_input.diff
index 20f03a4487520c28896c9d007a78b94491f6ddc5..52e2d68760eea6f54771f311094600b90bf125ce 100644
--- a/tutorial/solutions_sequential/Ex1_a_input.diff
+++ b/tutorial/solutions_sequential/Ex1_a_input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,5 +1,5 @@
  [TimeManager]
 -TEnd = 100000 # duration of the simulation [s]
diff --git a/tutorial/solutions_sequential/Ex1_a_problem.diff b/tutorial/solutions_sequential/Ex1_a_problem.diff
index 1e89feb8ec90e50ed7b1b09e37d1e10e7d36a1c3..683ea8b3cb2b0d68a098588b33b543e19d42cf6a 100644
--- a/tutorial/solutions_sequential/Ex1_a_problem.diff
+++ b/tutorial/solutions_sequential/Ex1_a_problem.diff
@@ -1,7 +1,7 @@
-Index: tutorialproblem_decoupled.hh
+Index: tutorialproblem_sequential.hh
 ===================================================================
---- tutorialproblem_decoupled.hh	(revision 15068)
-+++ tutorialproblem_decoupled.hh	(working copy)
+--- tutorialproblem_sequential.hh	(revision 15068)
++++ tutorialproblem_sequential.hh	(working copy)
 @@ -135,8 +135,8 @@
      TutorialProblemSequential(TimeManager &timeManager, const GridView &gridView)
          : ParentType(timeManager, gridView), eps_(1e-6)/*@\label{tutorial-sequential:constructor-problem}@*/
diff --git a/tutorial/solutions_sequential/Ex1_b_input.diff b/tutorial/solutions_sequential/Ex1_b_input.diff
index b24baf8e5f93e3959b17d808fa9e39f6d78b63ba..a336cba9022014eb214f7d0bfe4f40ff910bb303 100644
--- a/tutorial/solutions_sequential/Ex1_b_input.diff
+++ b/tutorial/solutions_sequential/Ex1_b_input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,9 +1,9 @@
  [TimeManager]
 -TEnd = 100000 # duration of the simulation [s]
diff --git a/tutorial/solutions_sequential/Ex1_b_problem.diff b/tutorial/solutions_sequential/Ex1_b_problem.diff
index 4a07b31ca0e3bc02c9c5b9cbddc573e58ec937a5..219a374e448011b179f2a92dc9fd950d5fa9b946 100644
--- a/tutorial/solutions_sequential/Ex1_b_problem.diff
+++ b/tutorial/solutions_sequential/Ex1_b_problem.diff
@@ -1,7 +1,7 @@
-Index: tutorialproblem_decoupled.hh
+Index: tutorialproblem_sequential.hh
 ===================================================================
---- tutorialproblem_decoupled.hh	(revision 15171)
-+++ tutorialproblem_decoupled.hh	(working copy)
+--- tutorialproblem_sequential.hh	(revision 15171)
++++ tutorialproblem_sequential.hh	(working copy)
 @@ -215,7 +215,7 @@
       */
      void boundaryTypesAtPos(BoundaryTypes &bcTypes, const GlobalPosition& globalPos) const /*@\label{tutorial-sequential:bctype}@*/
diff --git a/tutorial/solutions_sequential/Ex1_c_problem.diff b/tutorial/solutions_sequential/Ex1_c_problem.diff
index efa4ebc7fab32c431156ce2823178ccd372018eb..c9d3cda131836fb9b5d25d23db031b42a67437a9 100644
--- a/tutorial/solutions_sequential/Ex1_c_problem.diff
+++ b/tutorial/solutions_sequential/Ex1_c_problem.diff
@@ -1,7 +1,7 @@
-Index: tutorialproblem_decoupled.hh
+Index: tutorialproblem_sequential.hh
 ===================================================================
---- tutorialproblem_decoupled.hh	(revision 15068)
-+++ tutorialproblem_decoupled.hh	(working copy)
+--- tutorialproblem_sequential.hh	(revision 15068)
++++ tutorialproblem_sequential.hh	(working copy)
 @@ -41,7 +41,8 @@
  
  // the components that are used
diff --git a/tutorial/solutions_sequential/Ex1_d_input.diff b/tutorial/solutions_sequential/Ex1_d_input.diff
index 77ff8d26fe3bd6b600f7c3fc222a8ea3b887185a..f865155e9c07fa21f65ecea47302633188f3b70a 100644
--- a/tutorial/solutions_sequential/Ex1_d_input.diff
+++ b/tutorial/solutions_sequential/Ex1_d_input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,9 +1,9 @@
  [TimeManager]
 -TEnd = 100000 # duration of the simulation [s]
diff --git a/tutorial/solutions_sequential/Ex1_d_problem.diff b/tutorial/solutions_sequential/Ex1_d_problem.diff
index 1a66ff9d406713271c8c68b0ddaab66ae6a9434f..a2d1e1a25f88087857adf442971cc03001836923 100644
--- a/tutorial/solutions_sequential/Ex1_d_problem.diff
+++ b/tutorial/solutions_sequential/Ex1_d_problem.diff
@@ -1,7 +1,7 @@
-Index: tutorialproblem_decoupled.hh
+Index: tutorialproblem_sequential.hh
 ===================================================================
---- tutorialproblem_decoupled.hh	(revision 15068)
-+++ tutorialproblem_decoupled.hh	(working copy)
+--- tutorialproblem_sequential.hh	(revision 15068)
++++ tutorialproblem_sequential.hh	(working copy)
 @@ -42,7 +42,8 @@
  // the components that are used
  #include <dumux/material/components/h2o.hh>
diff --git a/tutorial/solutions_sequential/Ex1_e_input.diff b/tutorial/solutions_sequential/Ex1_e_input.diff
index 6022d68db1f51c4fda634225702db3f39ccc55a5..ed85c4f3530e4d599995337a31a7a7bea7e05943 100644
--- a/tutorial/solutions_sequential/Ex1_e_input.diff
+++ b/tutorial/solutions_sequential/Ex1_e_input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,9 +1,9 @@
  [TimeManager]
 -TEnd = 100000 # duration of the simulation [s]
diff --git a/tutorial/solutions_sequential/Ex1_e_spatialparams.diff b/tutorial/solutions_sequential/Ex1_e_spatialparams.diff
index 9c6bff26f3472d928d3144492bffdddd0662952c..b22e294cec8d0397d472928612b8626c522da12b 100644
--- a/tutorial/solutions_sequential/Ex1_e_spatialparams.diff
+++ b/tutorial/solutions_sequential/Ex1_e_spatialparams.diff
@@ -1,7 +1,7 @@
-Index: tutorialspatialparams_decoupled.hh
+Index: tutorialspatialparams_sequential.hh
 ===================================================================
---- tutorialspatialparams_decoupled.hh	(revision 15068)
-+++ tutorialspatialparams_decoupled.hh	(working copy)
+--- tutorialspatialparams_sequential.hh	(revision 15068)
++++ tutorialspatialparams_sequential.hh	(working copy)
 @@ -88,10 +88,13 @@
       *  Alternatively, the function intrinsicPermeabilityAtPos(const GlobalPosition& globalPos) could be
       *  defined, where globalPos is the vector including the global coordinates of the finite volume.
diff --git a/tutorial/solutions_sequential/Ex2_tutorial_sequential.input.diff b/tutorial/solutions_sequential/Ex2_tutorial_sequential.input.diff
index 89a758b565aad4bb0c71e641544cd20795626ebe..1fe26c9b02c6ef226317229ac3a3f49976670ca0 100644
--- a/tutorial/solutions_sequential/Ex2_tutorial_sequential.input.diff
+++ b/tutorial/solutions_sequential/Ex2_tutorial_sequential.input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,9 +1,9 @@
  [TimeManager]
 -TEnd = 100000 # duration of the simulation [s]
diff --git a/tutorial/solutions_sequential/Ex3tutorial_sequential.input.diff b/tutorial/solutions_sequential/Ex3tutorial_sequential.input.diff
index ef7dd84ed3d0f4b9352a80d8c4c1c4e0ee0b4b2e..ea65e2362a19315ee8e264745f252997a3b248e9 100644
--- a/tutorial/solutions_sequential/Ex3tutorial_sequential.input.diff
+++ b/tutorial/solutions_sequential/Ex3tutorial_sequential.input.diff
@@ -1,7 +1,7 @@
-Index: tutorial_decoupled.input
+Index: tutorial_sequential.input
 ===================================================================
---- tutorial_decoupled.input	(revision 15171)
-+++ tutorial_decoupled.input	(working copy)
+--- tutorial_sequential.input	(revision 15171)
++++ tutorial_sequential.input	(working copy)
 @@ -1,3 +1,10 @@
 +[Problem]
 +OutflowRateOil = 3e-2 # Rate of oil outflow for the Neumann boundary
diff --git a/tutorial/solutions_sequential/Ex3tutorialproblem_sequential.diff b/tutorial/solutions_sequential/Ex3tutorialproblem_sequential.diff
index 0408d9dac90c3a6e044d9aaa4cccaf38f6802bce..6e21463b31977336fb21187350f2089ed08cc426 100644
--- a/tutorial/solutions_sequential/Ex3tutorialproblem_sequential.diff
+++ b/tutorial/solutions_sequential/Ex3tutorialproblem_sequential.diff
@@ -1,7 +1,7 @@
-Index: tutorialproblem_decoupled.hh
+Index: tutorialproblem_sequential.hh
 ===================================================================
---- tutorialproblem_decoupled.hh	(revision 15068)
-+++ tutorialproblem_decoupled.hh	(working copy)
+--- tutorialproblem_sequential.hh	(revision 15068)
++++ tutorialproblem_sequential.hh	(working copy)
 @@ -135,8 +135,23 @@
      TutorialProblemSequential(TimeManager &timeManager, const GridView &gridView)
          : ParentType(timeManager, gridView), eps_(1e-6)/*@\label{tutorial-sequential:constructor-problem}@*/
diff --git a/tutorial/solutions_sequential/Ex3tutorialspatialparams_sequential.diff b/tutorial/solutions_sequential/Ex3tutorialspatialparams_sequential.diff
index 918790479169cf5640dcc775a67d86ae011b8910..029af6d04850a92d26037e476c9fe90fa09800fe 100644
--- a/tutorial/solutions_sequential/Ex3tutorialspatialparams_sequential.diff
+++ b/tutorial/solutions_sequential/Ex3tutorialspatialparams_sequential.diff
@@ -1,7 +1,7 @@
-Index: tutorialspatialparams_decoupled.hh
+Index: tutorialspatialparams_sequential.hh
 ===================================================================
---- tutorialspatialparams_decoupled.hh	(revision 15068)
-+++ tutorialspatialparams_decoupled.hh	(working copy)
+--- tutorialspatialparams_sequential.hh	(revision 15068)
++++ tutorialspatialparams_sequential.hh	(working copy)
 @@ -103,7 +103,7 @@
       */
      double porosity(const Element& element) const
diff --git a/tutorial/solutions_sequential/ex2tutorialspatialparams_sequential.hh b/tutorial/solutions_sequential/ex2tutorialspatialparams_sequential.hh
index 52254f5254d46d135d861099d9c50647dd720e87..685e973d8a36591648e3a5d8040918f7d1c3d39a 100644
--- a/tutorial/solutions_sequential/ex2tutorialspatialparams_sequential.hh
+++ b/tutorial/solutions_sequential/ex2tutorialspatialparams_sequential.hh
@@ -58,7 +58,7 @@ public:
 };
 }
 
-//! Definition of the spatial parameters for the decoupled tutorial
+//! Definition of the spatial parameters for the sequential tutorial
 
 template<class TypeTag>
 class Ex2TutorialSpatialParamsSequential: public FVSpatialParams<TypeTag>
diff --git a/tutorial/solutions_sequential/ex5_tutorialspatialparams_sequential.hh b/tutorial/solutions_sequential/ex5_tutorialspatialparams_sequential.hh
index c52508d70fad5165d8c436f1c623f037b0509e19..576776af20d615f540c74758300e4f66e9fb13c9 100644
--- a/tutorial/solutions_sequential/ex5_tutorialspatialparams_sequential.hh
+++ b/tutorial/solutions_sequential/ex5_tutorialspatialparams_sequential.hh
@@ -58,7 +58,7 @@ public:
 };
 }
 
-//! Definition of the spatial parameters for the decoupled tutorial
+//! Definition of the spatial parameters for the sequential tutorial
 
 template<class TypeTag>
 class Ex5TutorialSpatialParamsSequential: public FVSpatialParams<TypeTag>
diff --git a/tutorial/tutorialproblem_sequential.hh b/tutorial/tutorialproblem_sequential.hh
index 6e8117b23c94682436af92b1ee3f8ded9a77a443..8b26ce1e2ee58e87e0a81e7b336b60456d84484f 100644
--- a/tutorial/tutorialproblem_sequential.hh
+++ b/tutorial/tutorialproblem_sequential.hh
@@ -28,7 +28,7 @@
 #include <dune/grid/yaspgrid.hh>
 #include <dumux/io/cubegridcreator.hh>
 
-// dumux 2p-decoupled environment
+// dumux 2p-sequential environment
 #include <dumux/porousmediumflow/2p/sequential/diffusion/cellcentered/pressureproperties.hh>
 #include <dumux/porousmediumflow/2p/sequential/transport/cellcentered/properties.hh>
 #include <dumux/porousmediumflow/2p/sequential/impes/problem.hh> /*@\label{tutorial-sequential:parent-problem}@*/
@@ -96,7 +96,7 @@ SET_BOOL_PROP(TutorialProblemSequential, ProblemEnableGravity, false); /*@\label
 } /*@\label{tutorial-sequential:propertysystem-end}@*/
 
 /*! \ingroup SequentialProblems
- * @brief Problem class for the decoupled tutorial
+ * @brief Problem class for the sequential tutorial
 */
 template<class TypeTag>
 class TutorialProblemSequential: public IMPESProblem2P<TypeTag> /*@\label{tutorial-sequential:def-problem}@*/
diff --git a/tutorial/tutorialspatialparams_sequential.hh b/tutorial/tutorialspatialparams_sequential.hh
index a150d86e2fa8a397986beb0000212fddf12534b5..04ec71ee5dd6a21e381e6549f44978a30e26819c 100644
--- a/tutorial/tutorialspatialparams_sequential.hh
+++ b/tutorial/tutorialspatialparams_sequential.hh
@@ -58,7 +58,7 @@ public:
 };
 }
 
-//! Definition of the spatial parameters for the decoupled tutorial
+//! Definition of the spatial parameters for the sequential tutorial
 
 template<class TypeTag>
 class TutorialSpatialParamsSequential: public FVSpatialParams<TypeTag>
diff --git a/tutorial/solutions_sequential/ex2tutorialproblem_sequential.hh b/tutorial/solutions_sequential/ex2tutorialproblem_sequential.hh
index 53d9c56a8ba5abdf5ba9616b2ff01bed5605030e..6aa582288d915f06e249163ad77c5b0f70c0c208 100644
--- a/tutorial/solutions_sequential/ex2tutorialproblem_sequential.hh
+++ b/tutorial/solutions_sequential/ex2tutorialproblem_sequential.hh
@@ -96,7 +96,7 @@ SET_BOOL_PROP(Ex2TutorialProblemSequential, ProblemEnableGravity, false); /*@\la
 } /*@\label{tutorial-sequential:propertysystem-end}@*/
 
 /*! \ingroup SequentialProblems
  * @brief Problem class for the decoupled tutorial
 */
 template<class TypeTag>
 class Ex2TutorialProblemSequential: public IMPESProblem2P<TypeTag> /*@\label{tutorial-sequential:def-problem}@*/
@@ -144,7 +144,7 @@ public:
     */
     const char *name() const    /*@\label{tutorial-sequential:name}@*/
     {
-        return "tutorial_decoupled";
+        return "tutorial_sequential";
     }
 
     //!  Returns true if a restart file should be written.
@@ -96,7 +96,7 @@ SET_BOOL_PROP(Ex2TutorialProblemSequential, ProblemEnableGravity, false); /*@\la
 
 /*! \ingroup SequentialProblems
- * @brief Problem class for the decoupled tutorial
+ * @brief Problem class for the sequential tutorial
 */
 template<class TypeTag>
diff --git a/tutorial/solutions_sequential/ex5_tutorialproblem_sequential.hh b/tutorial/solutions_sequential/ex5_tutorialproblem_sequential.hh
index 63f61ccd7ef9a485557ca5f2202196ee410d62db..65ccbd29386fc6f23b019ca17494825cf969d2c7 100644
--- a/tutorial/solutions_sequential/ex5_tutorialproblem_sequential.hh
+++ b/tutorial/solutions_sequential/ex5_tutorialproblem_sequential.hh
@@ -97,7 +97,7 @@ SET_BOOL_PROP(Ex5TutorialProblemSequential, ProblemEnableGravity, false); /*@\la
 } /*@\label{tutorial-sequential:propertysystem-end}@*/
 
 /*! \ingroup SequentialProblems
  * @brief Problem class for the decoupled tutorial
 */
 template<class TypeTag>
 class Ex5TutorialProblemSequential: public IMPESProblem2P<TypeTag> /*@\label{tutorial-sequential:def-problem}@*/
@@ -145,7 +145,7 @@ public:
     */
     const char *name() const    /*@\label{tutorial-sequential:name}@*/
     {
-        return "ex5_tutorial_decoupled";
+        return "ex5_tutorial_sequential";
     }
 
     //!  Returns true if a restart file should be written.
@@ -97,7 +97,7 @@ SET_BOOL_PROP(Ex5TutorialProblemSequential, ProblemEnableGravity, false); /*@\la
 
 /*! \ingroup SequentialProblems
- * @brief Problem class for the decoupled tutorial
+ * @brief Problem class for the sequential tutorial
 */
 template<class TypeTag>